<!DOCTYPE html>
<html lang="en">

<head>
  {% block head %}
  <link rel="stylesheet" href="/static/reset.css">
  <link rel="stylesheet" href="/static/reveal.css">
  <!-- <link rel="stylesheet" href="/static/theme/black.css"> -->
  <!-- <link rel="stylesheet" href="/static/theme/solarized.css"> -->
  <!-- <link rel="stylesheet" href="/static/theme/white.css"> -->
   <link rel="stylesheet" href="/static/theme/night.css">
  <link rel="stylesheet" href="/static/tablequiz.css">
  <link rel="stylesheet" href="/static/plugin/highlight/monokai.css">
  <title>{% block title %}{% endblock %}</title>
  {% endblock %}
</head>

<body>
  {% block content %}{% endblock %}
</body>

{% block script %}
<script src="/static/reveal.js"></script>
<script src="/static/plugin/notes/notes.js"></script>
<script src="/static/plugin/markdown/markdown.js"></script>
<script src="/static/plugin/highlight/highlight.js"></script>
{% endblock %}

</html>
