{% extends "base.html" %}

{% block content %}
<div class="reveal">
  <div class="slides">
    {% block slides %}{% endblock %}
  </div>
</div>
{% endblock %}


{% block script %}
{{ super() }}
<script>
  // More info about initialization & config:
  // - https://revealjs.com/initialization/
  // - https://revealjs.com/config/
  Reveal.initialize({
    controls: true,  // hide the arrows
    progress: false, // hide the progress bar
    overview: false,  // don't accidentally reveal the questions!
    navigationMode: 'default',

    hash: true,
    // The "normal" size of the presentation, aspect ratio will
    // be preserved when the presentation is scaled to fit different
    // resolutions. Can be specified using percentage units.
    width: 960,
    height: 700,

    // Factor of the display size that should remain empty around
    // the content
    margin: 0.02,

    // Bounds for smallest/largest possible scale to apply to content
    minScale: 0.2,
    maxScale: 2.0,

    // Learn about plugins: https://revealjs.com/plugins/
    plugins: [RevealMarkdown, RevealHighlight]
  });
</script>
{% endblock %}
