{% extends "quiz_base.html" %}
{% import "macros.html" as macros %}
{% block title %}{{round.title}}{% endblock %}

{% block slides %}
<section>
  {{ round.title }}
</section>
{% for question in round.questions %}
<section>
  <p>Question {{loop.index}}</p>

  {{macros.ask_question(question)}}
</section>
{% endfor %}

<section>
  <h2>Round Finished!</h2>
  <p><small><a href="#/1">(Back to questions)</a></small></p>
</section>
<section>
  <p><small><a href="/">(Back to rounds)</a></small></p>
</section>
{% endblock %}
